import os
import gc

import gtk
import gobject

import shutil

import sugar.env
import _sugar
from sugar import profile

from sugar.activity import activity

class SlideshowActivity(activity.Activity):
	def __init__(self, handle):
		activity.Activity.__init__(self, handle)

		self.set_title( "Slideshow Activity" )

		self._index = 0
		self._cursor_hidden = False
		self._hide_cursor_sid = 0
		self._image_paths = []

		eventbox = gtk.EventBox()
		self.add(eventbox)

		self._image = gtk.Image()
		eventbox.add(self._image)
		self._image.show()

		self._load_images()
		self._goto_image(0)

		self.add_events(gtk.gdk.POINTER_MOTION_MASK)

		self.connect('key-press-event', self._key_press_event_cb)
		self.connect('motion-notify-event', self._motion_notify_event_cb)
		eventbox.connect('button-press-event', self._button_press_cb)

		self.show_all()
		self._hide_cursor_later()

	def _show_cursor(self):
		if self._cursor_hidden:
			self.window.set_cursor(None)
			self._hide_cursor_later()
			self._cursor_hidden = False

	def _hide_cursor_later(self):
		if self._hide_cursor_sid > 0:
			gobject.source_remove(self._hide_cursor_sid)

		self._hide_cursor_sid = gobject.timeout_add(2000, self._hide_cursor_timeout)

	def _hide_cursor_timeout(self):
		self._hide_cursor()
		return False

	def _hide_cursor(self):
		pixmap = gtk.gdk.Pixmap(None, 1, 1, 1)
		color = gtk.gdk.Color()
		cursor = gtk.gdk.Cursor(pixmap, pixmap, color, color, 0, 0)
		self.window.set_cursor(cursor)

		self._cursor_hidden = True

	def _motion_notify_event_cb(self, widget, event):
		self._show_cursor()

	def _button_press_cb(self, widget, event):
		self._goto_image(self._index + 1)

	def _key_press_event_cb(self, widget, event):
		if event.keyval == gtk.keysyms.Left or \
			event.keyval == gtk.keysyms.Up:
			self._goto_image(self._index - 1)
		elif event.keyval == gtk.keysyms.Right or event.keyval == gtk.keysyms.Down:
			self._goto_image(self._index + 1)
		elif event.keyval == gtk.keysyms.h:
			self._goto_image(0)

	def _goto_image(self, index):
		self._load_images()

		if (index >= len(self._image_paths)):
			index = 0
		if (index < 0):
			index = len(self._image_paths)-1
		if 0 <= index < len(self._image_paths):
			pixbuf = gtk.gdk.pixbuf_new_from_file(self._image_paths[index])
			if pixbuf:
				self._image.set_from_pixbuf(pixbuf)
				self._index = index

		del pixbuf
		gc.collect()

	def _load_images(self):
		pic_path = sugar.env.get_profile_path()
		pic_path = os.path.join(os.path.dirname(pic_path), 'camera_stuff')
		if (not os.path.exists( pic_path )):
			os.mkdir( pic_path )

		self._image_paths = []
		for image_path in os.listdir(pic_path):
			self._image_paths.append(os.path.join(pic_path, image_path))
		self._image_paths.sort()

		if ( len(self._image_paths) == 0 ):
			#basepath = os.path.dirname(os.path.abspath(__file__))
			basepath = activity.get_bundle_path()
			shutil.copyfile( os.path.join(basepath, 'a.png'), os.path.join(pic_path, 'a.png') )
			shutil.copyfile( os.path.join(basepath, 'b.png'), os.path.join(pic_path, 'b.png') )
			shutil.copyfile( os.path.join(basepath, 'c.png'), os.path.join(pic_path, 'c.png') )
			shutil.copyfile( os.path.join(basepath, 'd.png'), os.path.join(pic_path, 'd.png') )
		for image_path in os.listdir(pic_path):
			self._image_paths.append(os.path.join(pic_path, image_path))
		self._image_paths.sort()
